@@ -32,7 +32,10 @@ void replaceValueInXSettingsdContents(QString &xSettingsdContents, const QString
         newConfigString = QStringLiteral("%1 %2\n").arg(paramName, paramValue.toString());
     }
 
-    if (xSettingsdContents.contains(regExp)) {
+    if (paramValue.isNull()) {
+        // unset value
+        xSettingsdContents.replace(regExp, QString());
+    } else if (xSettingsdContents.contains(regExp)) {
         xSettingsdContents.replace(regExp, newConfigString);
     } else {
         xSettingsdContents = newConfigString + xSettingsdContents;
@@ -85,4 +88,9 @@ void setValue(const QString &paramName, const QVariant &paramValue)
     xSettingsdConfig.write(xSettingsdConfigContents.toUtf8());
     reloadXSettingsd();
 }
+
+void unsetValue(const QString &paramName)
+{
+    setValue(paramName, QVariant());
+}
 }
